OC.L10N.register(
    "files",
    {
    "File could not be found" : "No at fatu a agatare s'archìviu",
    "Move or copy" : "Tràmuda o còpia",
    "Download" : "Iscàrriga",
    "Delete" : "Cantzella",
    "Tags" : "Etichetas",
    "Home" : "Pàgina printzipale",
    "Close" : "Serra",
    "Favorites" : "Preferidos",
    "Could not create folder \"{dir}\"" : "No at fatu a creare sa cartella \"{dir}\"",
    "This will stop your current uploads." : "Custu at a firmare is carrigamentos tuos atuales.",
    "Upload cancelled." : "Carrigamentu annulladu.",
    "Processing files …" : "Elaborende is archìvios ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No at fatu a carrigare {filename} ca est una cartella o tenet 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Non b'at logu, ses carrighende {size1} ma est abarradu isceti {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Sa cartella de destinatzione \"{dir}\" no esistit prus",
    "Not enough free space" : "Non b'at logu lìberu",
    "An unknown error has occurred" : "B'at àpidu un'errore disconnotu",
    "Uploading …" : "Carrighende ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Su carrigamentu de s'elementu no est suportadu.",
    "Target folder does not exist any more" : "Sa cartella de destinatzione no esistit prus",
    "Operation is blocked by access control" : "S'operatzione est blocada dae su controllu de intrada",
    "Error when assembling chunks, status code {status}" : "Errore in s'assentada de is blocos, còdighe de istadu {status}",
    "Actions" : "Atziones",
    "Rename" : "Torra a numenare",
    "Move" : "Tràmuda",
    "Copy" : "Còpia",
    "Choose target folder" : "Sèbera cartella de destinatzione",
    "Open" : "Aberi",
    "Delete file" : "Cantzella archìviu",
    "Delete folder" : "Cantzella cartella",
    "Disconnect storage" : "Disconnete archiviatzione",
    "Leave this share" : "Lassa custa cumpartzidura",
    "Could not load info for file \"{file}\"" : "No at fatu a carrigare informatziones de s'archìviu \"{file}\"",
    "Files" : "Archìvios",
    "Details" : "Detàllios",
    "Please select tag(s) to add to the selection" : "Seletziona eticheta(s) pro agiùnghere a sa seletzione",
    "Apply tag(s) to selection" : "Àplica eticheta(s) a sa seletzione",
    "Pending" : "In suspesu",
    "Unable to determine date" : "Non faghet a determinare sa data",
    "This operation is forbidden" : "Custa operatzione no est permìtida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Custa cartella no est a disponimentu, controlla is informes o cuntata s'amministratzione",
    "Storage is temporarily not available" : "S'archiviatzione immoe no est a disponimentu",
    "Could not move \"{file}\", target exists" : "No at fatu a tramudare \"{file}\", sa destinatzione esistit giai",
    "Could not move \"{file}\"" : "No at fatu a tramudare \"{file}\"",
    "copy" : "còpia",
    "Could not copy \"{file}\", target exists" : "No at fatu a copiare \"{file}\", sa destinatzione esistit giai",
    "Could not copy \"{file}\"" : "No at fatu a copiare \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} copiadu a intro de {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiados {origin} e {nbfiles} àteros archìvios a intro de {destination}",
    "{newName} already exists" : "{newName} esistit giai",
    "Could not rename \"{fileName}\", it does not exist any more" : "No at fatu a torrare a numenare \"{fileName}\", ca no esistit prus",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Su nùmene \"{targetName}\" est giai impreadu in sa cartella \"{dir}\". Sèbera un'àteru nùmene.",
    "Could not rename \"{fileName}\"" : "No at fatu a torrare a numenare \"{fileName}\"",
    "Could not create file \"{file}\"" : "No at fatu a creare s'archìviu \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No at fatu a creare s'archìviu \"{file}\" ca esitit giai",
    "Could not create folder \"{dir}\" because it already exists" : "No at fatu a creare sa cartella \"{dir}\" ca esistit giai",
    "Could not fetch file details \"{file}\"" : "No at fatu a recuperare is detàllios de s'archìviu \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Errore cantzellende s'archìviu \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Perunu resurtadu de chirca in àteras cartellas pro {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Inserta prus de duos caràteres pro chircare in àteras cartellas",
    "Name" : "Nùmene",
    "Size" : "Mannària",
    "Modified" : "Modificadu",
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartellas"],
    "_%n file_::_%n files_" : ["%n archìviu","%n archìvios"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclùdidu %n cuadu","inclùdidos %n cuados"],
    "_Uploading %n file_::_Uploading %n files_" : ["Carrighende %n archìviu","Carrighende %n archìvios"],
    "Select file range" : "Seletziona classe de archìviu",
    "{used} of {quota} used" : "{used} de {quota} impreadu",
    "{used} used" : "{used} impreadu",
    "\"{name}\" is an invalid file name." : "\"{name}\" est unu nùmene de archìviu non vàlidu.",
    "File name cannot be empty." : "Su nùmene de s'archìviu non podet èssere bòidu.",
    "\"/\" is not allowed inside a file name." : "\"/\" no est permìtidu in unu nùmene de archìviu.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no est una genia de archìviu permìtida",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "S'archiviatzione de {owner} est prena, non podes prus carrigare o sincronizare archìvios!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Sa cartella de grupu \"{mountPoint}\" est prena, non podes prus carrigare o sincronizare archìvios!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "S'archiviatzione de foras \"{mountPoint}\" est prena, non podes prus carrigare o sincronizare archìvios!",
    "Your storage is full, files cannot be updated or synced anymore!" : "S'archiviatzione est prena, non podes prus carrigare o sincronizare archìvios!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "S'archiviatzione de {owner} est giai prena ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Sa cartella de grupu \"{mountPoint}\" est giai prena ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "S'archiviatzione esterna \"{mountPoint}\" est giai prena ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "S'archiviatzione tua est giai prena ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["currispondet '{filter}'","currispondent '{filter}'"],
    "View in folder" : "Visualiza in sa cartella",
    "Path" : "Percursu",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Preferidu",
    "Favorite" : "Preferidu",
    "Copy direct link (only works for users who have access to this file/folder)" : "Còpia ligòngiu deretu (faghet isceti pro utentes chi tenent atzessu a custu archìviu/cartella)",
    "You can only favorite a single file or folder at a time" : "Podes preferire isceti un'archìviu o una cartella cada borta",
    "New folder" : "Cartella noa",
    "Upload file" : "Carriga archìviu",
    "Recent" : "Reghente",
    "Not favorited" : "Non preferidu",
    "Remove from favorites" : "Boga dae preferidos",
    "Add to favorites" : "Agiunghe a preferidos",
    "An error occurred while trying to update the tags" : "B'at àpidu un'errore proende a agiornare is etichetas",
    "Added to favorites" : "Agiuntu a preferidos",
    "Removed from favorites" : "Bogadu dae preferidos",
    "You added {file} to your favorites" : "As agiuntu {file} a preferidos",
    "You removed {file} from your favorites" : "As bogadu {file} dae preferidos",
    "File changes" : "Modìficas de s'archìviu",
    "Created by {user}" : "Creadu dae {user}",
    "Changed by {user}" : "Modificadu dae {user}",
    "Deleted by {user}" : "Cantzelladu dae{user}",
    "Restored by {user}" : "Ripristinadu dae {user}",
    "Renamed by {user}" : "Torradu a numenare dae {user}",
    "Moved by {user}" : "Tramudadu dae {user}",
    "\"remote user\"" : "\"utèntzia remota\"",
    "You created {file}" : "As creadu {file}",
    "You created an encrypted file in {file}" : "As creadu un'archìviu tzifradu in {file}",
    "{user} created {file}" : "{user} at creadu {file}",
    "{user} created an encrypted file in {file}" : "{user} at creadu un'archìviu tzifradu in {file}",
    "{file} was created in a public folder" : "{file} s'est creadu in una cartella pùblica",
    "You changed {file}" : "As cambiadu {file}",
    "You changed an encrypted file in {file}" : "As cambiadu un'archìviu tzifradu in {file}",
    "{user} changed {file}" : "{user} at cambiadu {file}",
    "{user} changed an encrypted file in {file}" : "{user} at cambiadu un'archìviu tzifradu in {file}",
    "You deleted {file}" : "As cantzelladu {file}",
    "You deleted an encrypted file in {file}" : "As cantzelladu un'archìviu tzifradu in {file}",
    "{user} deleted {file}" : "{user} at cantzelladu {file}",
    "{user} deleted an encrypted file in {file}" : "{user} at cantzelladu un'archìviu tzifradu in {file}",
    "You restored {file}" : "As recuperadu {file}",
    "{user} restored {file}" : "{user} at recuperadu {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "As torradu a numenare {oldfile} (hidden) cun {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "As torradu a numenare {oldfile} (hidden) cun {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "As torradu a numenare {oldfile} cun {newfile} (hidden)",
    "You renamed {oldfile} to {newfile}" : "As torradu a numenare {oldfile} cun {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} at torradu a numenare {oldfile} (hidden) cun {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} at torradu a numenare {oldfile} (hidden) cun {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} at torradu a numenare {oldfile} cun {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "{user} at torradu a numenare {oldfile} cun {newfile}",
    "You moved {oldfile} to {newfile}" : "As tramudadu {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} at tramudadu {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Ant agiuntu o bogadu un'archìviu dae is <strong>preferidos</strong>",
    "A file or folder has been <strong>changed</strong>" : "Ant <strong>cambiadu</strong> un'archìviu o una cartella",
    "A favorite file or folder has been <strong>changed</strong>" : "Ant <strong>cambiadu</strong>un'archìviu o una cartella preferida",
    "All files" : "Totu is archìvios",
    "Upload (max. %s)" : "Càrriga (max. %s)",
    "Accept" : "Atzeta",
    "Reject" : "Refuda",
    "Incoming ownership transfer from {user}" : "Tràmuda de propriedade in intrada dae {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Boles atzetare {path}?\n\nNota: Su protzessu de tràmuda a pustis chi atzetas podet istentare fintzas un'ora.",
    "Ownership transfer failed" : "Tràmuda de propriedade faddida",
    "Your ownership transfer of {path} to {user} failed." : "Tràmuda de propriedade de {path} a {user} faddida.",
    "The ownership transfer of {path} from {user} failed." : "Tràmuda de propriedade de {path} dae {user} faddida.",
    "Ownership transfer done" : "Tràmuda de propriedade fata",
    "Your ownership transfer of {path} to {user} has completed." : "Tràmuda de propriedade de {path} a {user} cumpletada.",
    "The ownership transfer of {path} from {user} has completed." : "Tràmuda de propriedade de {path} dae {user} cumpletada.",
    "in %s" : "in %s",
    "File Management" : "Gestione archìvios",
    "Select all" : "Seletziona totu",
    "Transfer ownership of a file or folder" : "Tràmuda propriedade de un'archìviu o una cartella",
    "Choose file or folder to transfer" : "Sèbera archìviu o cartella de tramudare",
    "Change" : "Càmbia",
    "New owner" : "Propriedade noa",
    "Choose a file or folder to transfer" : "Sèbera un'archìviu o una cartella de tramudare",
    "Transfer" : "Tràmuda",
    "Transfer {path} to {userid}" : "Tràmuda {path} a {userid}",
    "Invalid path selected" : "Percursu seletzionadu non vàlidu",
    "Unknown error" : "Errore disconnotu",
    "Ownership transfer request sent" : "Dimanda de tràmuda de propriedade imbiada",
    "No files in here" : "Perunu archìviu",
    "Go back" : "In segus",
    "Show hidden files" : "Mustra archìvios cuados",
    "Crop image previews" : "Retàllia anteprimas de s'imàgine",
    "Additional settings" : "Impostatziones in agiunta",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Còpia in is punta de billete",
    "Use this address to access your Files via WebDAV" : "Imprea custu indiritzu pro intrare in archìvios tràmite WebDAV",
    "Unable to change the favourite state of the file" : "Non faghet a cambiare s'istadu de preferidu de s'archìviu",
    "Error while loading the file data" : "Errore in su carrigamentu de is datos de s'archìviu",
    "Pick a template for {name}" : "Sèbera unu modellu pro {name}",
    "Cancel" : "Annulla",
    "Create" : "Crea",
    "Create a new file with the selected template" : "Crea un'archìviu nou cun su modellu seletzionadu",
    "Creating file" : "Creende s'archìviu",
    "Blank" : "Isbòidu",
    "Unable to create new file from template" : "Non faghet a creare un'archìviu nou dae su modellu",
    "Delete permanently" : "Cantzella in manera definitiva",
    "Set up templates folder" : "Imposta cartella de is modellos",
    "Templates" : "Modellos",
    "Unable to initialize the templates directory" : "Non faghet a initzializare sa cartella de is modellos",
    "Toggle %1$s sublist" : "Passa a sa sutalista %1$s",
    "Toggle grid view" : "Càmbia a visualizatzione in mosàicu",
    "Upload some content or sync with your devices!" : "Càrriga cuntenutos o sincroniza cun is dispositivos tuos!",
    "No entries found in this folder" : "Perunu elementu agatadu in custa cartella",
    "Upload too large" : "Carrigamentu tropu mannu",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Is archìvios chi boles carrigare passant sa mannària màssima de carrigamentu de archìvios in custu serbidore.",
    "No favorites yet" : "Ancora perunu preferidu",
    "Files and folders you mark as favorite will show up here" : "Is archìvios e is cartellas chi marcas comente preferidos ant a aparèssere inoghe",
    "Shares" : "Cumpartziduras",
    "Shared with others" : "Cumpartzidu cun àtere",
    "Shared with you" : "Cumpartzidu cun tegus",
    "Shared by link" : "Cumpartzidu cun ligòngiu",
    "Deleted shares" : "Cumpartziduras cantzelladas",
    "Pending shares" : "Cumpartziduras in suspesu",
    "Text file" : "Archìviu de testu",
    "New text file.txt" : "Archìviu de testu .txt nou",
    "Storage invalid" : "Archiviatzione non vàlida",
    "Select" : "Seletziona",
    "You don’t have permission to upload or create files here" : "Non tenes su permissu pro carrigare o creare archìvios inoghe",
    "New" : "Nou",
    "Copied!" : "Copiadu!",
    "Unlimited" : "Chene lìmites",
    "Search users" : "Chirca utentes",
    "Cannot transfer ownership of a file or folder you don't own" : "Non faghet a tramudare sa propriedade de un'archìviu o cartella de is chi non ses mere",
    "%s used" : "%s impreadu",
    "%1$s of %2$s used" : "%1$s de %2$s impreadu",
    "Settings" : "Impostatziones",
    "Deleted files" : "Archìvios cantzellados"
},
"nplurals=2; plural=(n != 1);");
